==> aleph-1.0.20-py3-none-any.whl: aleph/gui/ui_superposition.py <==
from PySide2 import QtWidgets, QtCore, QtWebEngineWidgets, QtGui

import os

class Ui_Superposition:
	def setupUI(self, Superposition):

		self.gridLayout = QtWidgets.QGridLayout(Superposition)
		self.gridLayout.setObjectName("gridLayout")

		self.splitter = QtWidgets.QSplitter(Superposition)
		self.splitter.setObjectName("splitter")
		self.splitter.setOrientation(QtCore.Qt.Vertical)
		self.splitter.setHandleWidth(15)
		#self.splitter.setStyleSheet("QSplitter::handle{image:url("+os.path.join(os.path.dirname(__file__),"img/splitter.png")+");}");

		self.topGroupBox = QtWidgets.QGroupBox(self.splitter)
		self.topGroupBox.setObjectName("topGroupBox")
		self.topGroupBox.setTitle("Superposition")
		
		self.topLayout = QtWidgets.QGridLayout(self.topGroupBox)
		self.topLayout.setObjectName("topLayout")

		self.titleLabel = QtWidgets.QLabel(self.topGroupBox)
		self.titleLabel.setObjectName("titleLabel")
		self.titleLabel.setText("Job title")
		self.topLayout.addWidget(self.titleLabel, 0, 0, 1, 1)
		self.titleLine = QtWidgets.QLineEdit(self.topGroupBox)
		self.titleLine.setObjectName("titleLine")
		self.titleLine.setFixedWidth(150)
		self.topLayout.addWidget(self.titleLine, 0, 1, 1, 1)

		self.referenceLabel = QtWidgets.QLabel(self.topGroupBox)
		self.referenceLabel.setObjectName("referenceLabel")
		self.referenceLabel.setText("Reference")
		self.topLayout.addWidget(self.referenceLabel, 1, 0, 1, 1)
		self.referenceLine = QtWidgets.QLineEdit(self.topGroupBox)
		self.referenceLine.setObjectName("referenceLine")
		self.topLayout.addWidget(self.referenceLine, 1, 1, 1, 1)
		self.referenceLoad = QtWidgets.QPushButton(self.topGroupBox)
		self.referenceLoad.setObjectName("referenceLoad")
		self.referenceLoad.setText("Browse")
		self.topLayout.addWidget(self.referenceLoad, 1, 2, 1, 1)

		self.fragmentRadio = QtWidgets.QRadioButton(self.topGroupBox)
		self.fragmentRadio.setObjectName("fragmentRadio")
		self.fragmentRadio.setText("Fragment")
		self.fragmentRadio.setChecked(True)
		self.topLayout.addWidget(self.fragmentRadio, 2, 0, 1, 1)
		self.fragmentLine = QtWidgets.QLineEdit(self.topGroupBox)
		self.fragmentLine.setObjectName("fragmentLine")
		self.topLayout.addWidget(self.fragmentLine, 2, 1, 1, 1)
		self.fragmentLoad = QtWidgets.QPushButton(self.topGroupBox)
		self.fragmentLoad.setObjectName("fragmentLoad")
		self.fragmentLoad.setText("Browse")
		self.topLayout.addWidget(self.fragmentLoad, 2, 2, 1, 1)

		self.fragmentDirRadio = QtWidgets.QRadioButton(self.topGroupBox)
		self.fragmentDirRadio.setObjectName("fragmentDirRadio")
		self.fragmentDirRadio.setText("Directory")
		self.topLayout.addWidget(self.fragmentDirRadio, 3, 0, 1, 1)
		self.fragmentDirLine = QtWidgets.QLineEdit(self.topGroupBox)
		self.fragmentDirLine.setObjectName("fragmentDirLine")
		self.topLayout.addWidget(self.fragmentDirLine, 3, 1, 1, 1)
		self.fragmentDirLoad = QtWidgets.QPushButton(self.topGroupBox)
		self.fragmentDirLoad.setObjectName("fragmentDirLoad")
		self.fragmentDirLoad.setText("Browse")
		self.topLayout.addWidget(self.fragmentDirLoad, 3, 2, 1, 1)

		self.line = QtWidgets.QFrame(self.topGroupBox)
		self.line.setFrameShape(QtWidgets.QFrame.VLine)
		self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
		self.line.setObjectName("line")
		self.topLayout.addWidget(self.line, 0, 3, 4, 1)

		self.intraLabel = QtWidgets.QLabel(self.topGroupBox)
		self.intraLabel.setObjectName("intraLabel")
		self.intraLabel.setText("Secondary structure match")
		self.topLayout.addWidget(self.intraLabel, 0, 4, 1, 1)
		self.intraSpin = QtWidgets.QSpinBox(self.topGroupBox)
		self.intraSpin.setObjectName("intraSpin")
		self.intraSpin.setMinimum(0)
		self.intraSpin.setMaximum(100)
		self.intraSpin.setSingleStep(10)
		self.intraSpin.setValue(95)
		self.topLayout.addWidget(self.intraSpin, 0, 5, 1, 1)

		self.interLabel = QtWidgets.QLabel(self.topGroupBox)
		self.interLabel.setObjectName("interLabel")
		self.interLabel.setText("Tertiary structure match")
		self.topLayout.addWidget(self.interLabel, 1, 4, 1, 1)
		self.interSpin = QtWidgets.QSpinBox(self.topGroupBox)
		self.interSpin.setObjectName("interSpin")
		self.interSpin.setMinimum(0)
		self.interSpin.setMaximum(100)
		self.interSpin.setSingleStep(10)
		self.interSpin.setValue(95)
		self.topLayout.addWidget(self.interSpin, 1, 5, 1, 1)

		self.rmsdLabel = QtWidgets.QLabel(self.topGroupBox)
		self.rmsdLabel.setObjectName("rmsdLabel")
		self.rmsdLabel.setText("Rmsd threshold")
		self.topLayout.addWidget(self.rmsdLabel, 2, 4, 1, 1)
		self.rmsdValue = QtWidgets.QDoubleSpinBox(self.topGroupBox)
		self.rmsdValue.setObjectName("rmsdValue")
		self.rmsdValue.setLocale(QtCore.QLocale.Spanish)
		self.rmsdValue.setValue(1.5)
		self.topLayout.addWidget(self.rmsdValue, 2, 5, 1,1)

		self.superposeCheck = QtWidgets.QCheckBox(self.topGroupBox)
		self.superposeCheck.setObjectName("superposeCheck")
		self.superposeCheck.setText("Superpose reference onto target")
		self.topLayout.addWidget(self.superposeCheck, 3, 4, 1, 2)		

		self.tabs = QtWidgets.QTabWidget(self.splitter)
		self.tabs.setObjectName("tabs")

		self.middleSplitter = QtWidgets.QSplitter(self.tabs)
		self.middleSplitter.setObjectName("middleSplitter")
		self.middleSplitter.setOrientation(QtCore.Qt.Horizontal)
		self.middleSplitter.setHandleWidth(10)
		#self.middleSplitter.setStyleSheet("QSplitter::handle{image:url("+os.path.join(os.path.dirname(__file__),"img/splitter_h.png")+");}");
		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
		self.middleSplitter.setSizePolicy(policy)

		self.tabs.addTab(self.middleSplitter, "General")

		self.tree = QtWidgets.QTreeView(self.middleSplitter)
		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
		self.tree.setSizePolicy(policy)
		self.model = QtWidgets.QFileSystemModel(self.tree)
		self.tree.setModel(self.model)
		self.model.setNameFilters(["*.pdb", "*.ent"])
		self.model.setNameFilterDisables(False)
		self.tree.hideColumn(1)
		self.tree.hideColumn(2)
		self.tree.header().hide()
		self.tree.header().setSectionResizeMode(QtWidgets.QHeaderView.Stretch)
		self.tree.sortByColumn(3, QtCore.Qt.AscendingOrder)
		self.tree.setSortingEnabled(True)
		self.tree.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)

		self.targetLayoutWidget = QtWidgets.QWidget(self.middleSplitter)
		self.targetLayoutWidget.setObjectName("targetLayoutWidget")

		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
		self.targetLayoutWidget.setSizePolicy(policy)

		self.targetLayout = QtWidgets.QGridLayout(self.targetLayoutWidget)
		self.targetLayout.setObjectName("targetLayout")
		self.targetLayout.setContentsMargins(0, 0, 0, 0)

		self.targetLabel = QtWidgets.QLabel(self.targetLayoutWidget)
		self.targetLabel.setObjectName("targetLabel")
		self.targetLabel.setText("Reference")
		self.targetLayout.addWidget(self.targetLabel, 0, 0, 1, 7)

		self.targetBrowser = QtWebEngineWidgets.QWebEngineView(self.targetLayoutWidget)
		self.targetBrowser.setObjectName("targetBrowser")
		self.targetBrowser.page().setBackgroundColor(QtCore.Qt.black)
		self.targetBrowser.setSizePolicy(policy)
		self.targetLayout.addWidget(self.targetBrowser, 1, 0, 1, 7)

		spacerItem = QtWidgets.QSpacerItem(40 ,20 ,QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
		self.targetLayout.addItem(spacerItem, 2, 0, 1, 1)

		self.representationLabel = QtWidgets.QLabel(self.targetLayoutWidget)
		self.representationLabel.setObjectName("representationLabel")
		self.representationLabel.setText("Representation")
		self.targetLayout.addWidget(self.representationLabel, 2, 1, 1, 1)
		self.representationValue = QtWidgets.QComboBox(self.targetLayoutWidget)
		self.representationValue.setObjectName("representationValue")
		self.representationValue.addItems(["cartoon" , "backbone", "licorice"])
		self.targetLayout.addWidget(self.representationValue, 2, 2, 1, 1)        
		self.colorLabel = QtWidgets.QLabel(self.targetLayoutWidget)
		self.colorLabel.setObjectName("colorLabel")
		self.colorLabel.setText("color")
		self.targetLayout.addWidget(self.colorLabel, 2, 3, 1, 1)
		self.colorValue = QtWidgets.QComboBox(self.targetLayoutWidget)
		self.colorValue.setObjectName("colorValue")
		self.colorValue.addItems(["secondary structure" , "residue", "chain id"])
		self.targetLayout.addWidget(self.colorValue, 2, 4, 1, 1)
		self.line3 = QtWidgets.QFrame(self.targetLayoutWidget)
		self.line3.setFrameShape(QtWidgets.QFrame.VLine)
		self.line3.setFrameShadow(QtWidgets.QFrame.Sunken)
		self.line3.setObjectName("line3")
		self.targetLayout.addWidget(self.line3, 2, 5, 1, 1)
		self.saveButton = QtWidgets.QPushButton(self.targetLayoutWidget)
		self.saveButton.setObjectName("saveButton")
		self.saveButton.setIcon(QtGui.QIcon(os.path.join(os.path.dirname(__file__),"img/screenshot.png")))
		self.targetLayout.addWidget(self.saveButton, 2, 6, 1, 1)

		self.referenceLayoutWidget = QtWidgets.QWidget(self.middleSplitter)
		self.referenceLayoutWidget.setObjectName("referenceLayoutWidget")

		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
		self.referenceLayoutWidget.setSizePolicy(policy)

		self.referenceLayout = QtWidgets.QGridLayout(self.referenceLayoutWidget)
		self.referenceLayout.setObjectName("referenceLayout")
		self.referenceLayout.setContentsMargins(0, 0, 0, 0)

		self.targetBrowserLabel = QtWidgets.QLabel(self.targetLayoutWidget)
		self.targetBrowserLabel.setObjectName("targetBrowserLabel")
		self.targetBrowserLabel.setText("Target")
		self.referenceLayout.addWidget(self.targetBrowserLabel, 0, 0, 1, 7)

		self.referenceBrowser = QtWebEngineWidgets.QWebEngineView(self.referenceLayoutWidget)
		self.referenceBrowser.setObjectName("referenceBrowser")
		self.referenceBrowser.page().setBackgroundColor(QtCore.Qt.black)
		self.referenceBrowser.setSizePolicy(policy)

		self.referenceLayout.addWidget(self.referenceBrowser, 1, 0, 1, 7)

		spacerItem = QtWidgets.QSpacerItem(40 ,20 ,QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
		self.referenceLayout.addItem(spacerItem, 2, 0, 1, 1)

		self.representationReferenceLabel = QtWidgets.QLabel(self.referenceLayoutWidget)
		self.representationReferenceLabel.setObjectName("representationReferenceLabel")
		self.representationReferenceLabel.setText("Representation")
		self.referenceLayout.addWidget(self.representationReferenceLabel, 2, 1, 1, 1)
		self.representationReferenceValue = QtWidgets.QComboBox(self.referenceLayoutWidget)
		self.representationReferenceValue.setObjectName("representationReferenceValue")
		self.representationReferenceValue.addItems(["cartoon" , "backbone", "licorice"])
		self.referenceLayout.addWidget(self.representationReferenceValue, 2, 2, 1, 1)        
		self.colorReferenceLabel = QtWidgets.QLabel(self.referenceLayoutWidget)
		self.colorReferenceLabel.setObjectName("colorReferenceLabel")
		self.colorReferenceLabel.setText("color")
		self.referenceLayout.addWidget(self.colorReferenceLabel, 2, 3, 1, 1)
		self.colorReferenceValue = QtWidgets.QComboBox(self.referenceLayoutWidget)
		self.colorReferenceValue.setObjectName("colorReferenceValue")
		self.colorReferenceValue.addItems(["secondary structure" , "residue", "chain id"])
		self.referenceLayout.addWidget(self.colorReferenceValue, 2, 4, 1, 1)
		self.line4 = QtWidgets.QFrame(self.referenceLayoutWidget)
		self.line4.setFrameShape(QtWidgets.QFrame.VLine)
		self.line4.setFrameShadow(QtWidgets.QFrame.Sunken)
		self.line4.setObjectName("line4")
		self.referenceLayout.addWidget(self.line4, 2, 5, 1, 1)
		self.saveButton2 = QtWidgets.QPushButton(self.referenceLayoutWidget)
		self.saveButton2.setObjectName("saveButton2")
		self.saveButton2.setIcon(QtGui.QIcon(os.path.join(os.path.dirname(__file__),"img/screenshot.png")))
		self.referenceLayout.addWidget(self.saveButton2, 2, 6, 1, 1) 

		self.advancedWidget = QtWidgets.QWidget(self.tabs)
		self.tabs.addTab(self.advancedWidget, "Advanced")

		self.advancedWidget.setObjectName("advancedWidget")
		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
		self.advancedWidget.setSizePolicy(policy)

		self.advancedLayout = QtWidgets.QGridLayout(self.advancedWidget)
		self.advancedLayout.setObjectName("advancedLayout")
		self.advancedLayout.setContentsMargins(0, 0, 0, 0)

		self.textOutput = QtWidgets.QTextEdit(self.splitter)
		self.textOutput.setObjectName("textOutput")
		self.textOutput.setReadOnly(True)

		self.gridLayout.addWidget(self.splitter, 0, 0, 1, 1)

==> aleph-1.1.0-py3-none-any.whl: aleph/gui/ui_superposition.py <==
from PySide2 import QtWidgets, QtCore, QtWebEngineWidgets, QtGui

import os

class Ui_Superposition:
	def setupUI(self, Superposition):

		self.gridLayout = QtWidgets.QGridLayout(Superposition)
		self.gridLayout.setObjectName("gridLayout")

		self.splitter = QtWidgets.QSplitter(Superposition)
		self.splitter.setObjectName("splitter")
		self.splitter.setOrientation(QtCore.Qt.Vertical)
		self.splitter.setHandleWidth(15)
		#self.splitter.setStyleSheet("QSplitter::handle{image:url("+os.path.join(os.path.dirname(__file__),"img/splitter.png")+");}");

		self.topGroupBox = QtWidgets.QGroupBox(self.splitter)
		self.topGroupBox.setObjectName("topGroupBox")
		self.topGroupBox.setTitle("Superposition")
		
		self.topLayout = QtWidgets.QGridLayout(self.topGroupBox)
		self.topLayout.setObjectName("topLayout")

		self.titleLabel = QtWidgets.QLabel(self.topGroupBox)
		self.titleLabel.setObjectName("titleLabel")
		self.titleLabel.setText("Job title")
		self.topLayout.addWidget(self.titleLabel, 0, 0, 1, 1)
		self.titleLine = QtWidgets.QLineEdit(self.topGroupBox)
		self.titleLine.setObjectName("titleLine")
		self.titleLine.setFixedWidth(150)
		self.topLayout.addWidget(self.titleLine, 0, 1, 1, 1)

		self.referenceLabel = QtWidgets.QLabel(self.topGroupBox)
		self.referenceLabel.setObjectName("referenceLabel")
		self.referenceLabel.setText("Reference")
		self.topLayout.addWidget(self.referenceLabel, 1, 0, 1, 1)
		self.referenceLine = QtWidgets.QLineEdit(self.topGroupBox)
		self.referenceLine.setObjectName("referenceLine")
		self.topLayout.addWidget(self.referenceLine, 1, 1, 1, 1)
		self.referenceLoad = QtWidgets.QPushButton(self.topGroupBox)
		self.referenceLoad.setObjectName("referenceLoad")
		self.referenceLoad.setText("Browse")
		self.topLayout.addWidget(self.referenceLoad, 1, 2, 1, 1)

		self.fragmentRadio = QtWidgets.QRadioButton(self.topGroupBox)
		self.fragmentRadio.setObjectName("fragmentRadio")
		self.fragmentRadio.setText("Fragment")
		self.fragmentRadio.setChecked(True)
		self.topLayout.addWidget(self.fragmentRadio, 2, 0, 1, 1)
		self.fragmentLine = QtWidgets.QLineEdit(self.topGroupBox)
		self.fragmentLine.setObjectName("fragmentLine")
		self.topLayout.addWidget(self.fragmentLine, 2, 1, 1, 1)
		self.fragmentLoad = QtWidgets.QPushButton(self.topGroupBox)
		self.fragmentLoad.setObjectName("fragmentLoad")
		self.fragmentLoad.setText("Browse")
		self.topLayout.addWidget(self.fragmentLoad, 2, 2, 1, 1)

		self.fragmentDirRadio = QtWidgets.QRadioButton(self.topGroupBox)
		self.fragmentDirRadio.setObjectName("fragmentDirRadio")
		self.fragmentDirRadio.setText("Directory")
		self.topLayout.addWidget(self.fragmentDirRadio, 3, 0, 1, 1)
		self.fragmentDirLine = QtWidgets.QLineEdit(self.topGroupBox)
		self.fragmentDirLine.setObjectName("fragmentDirLine")
		self.topLayout.addWidget(self.fragmentDirLine, 3, 1, 1, 1)
		self.fragmentDirLoad = QtWidgets.QPushButton(self.topGroupBox)
		self.fragmentDirLoad.setObjectName("fragmentDirLoad")
		self.fragmentDirLoad.setText("Browse")
		self.topLayout.addWidget(self.fragmentDirLoad, 3, 2, 1, 1)

		self.line = QtWidgets.QFrame(self.topGroupBox)
		self.line.setFrameShape(QtWidgets.QFrame.VLine)
		self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
		self.line.setObjectName("line")
		self.topLayout.addWidget(self.line, 0, 3, 4, 1)

		self.intraLabel = QtWidgets.QLabel(self.topGroupBox)
		self.intraLabel.setObjectName("intraLabel")
		self.intraLabel.setText("Secondary structure match")
		self.topLayout.addWidget(self.intraLabel, 0, 4, 1, 1)
		self.intraSpin = QtWidgets.QSpinBox(self.topGroupBox)
		self.intraSpin.setObjectName("intraSpin")
		self.intraSpin.setMinimum(0)
		self.intraSpin.setMaximum(100)
		self.intraSpin.setSingleStep(10)
		self.intraSpin.setValue(95)
		self.topLayout.addWidget(self.intraSpin, 0, 5, 1, 1)

		self.interLabel = QtWidgets.QLabel(self.topGroupBox)
		self.interLabel.setObjectName("interLabel")
		self.interLabel.setText("Tertiary structure match")
		self.topLayout.addWidget(self.interLabel, 1, 4, 1, 1)
		self.interSpin = QtWidgets.QSpinBox(self.topGroupBox)
		self.interSpin.setObjectName("interSpin")
		self.interSpin.setMinimum(0)
		self.interSpin.setMaximum(100)
		self.interSpin.setSingleStep(10)
		self.interSpin.setValue(95)
		self.topLayout.addWidget(self.interSpin, 1, 5, 1, 1)

		self.rmsdLabel = QtWidgets.QLabel(self.topGroupBox)
		self.rmsdLabel.setObjectName("rmsdLabel")
		self.rmsdLabel.setText("Rmsd threshold")
		self.topLayout.addWidget(self.rmsdLabel, 2, 4, 1, 1)
		self.rmsdValue = QtWidgets.QDoubleSpinBox(self.topGroupBox)
		self.rmsdValue.setObjectName("rmsdValue")
		self.rmsdValue.setValue(1.5)
		self.topLayout.addWidget(self.rmsdValue, 2, 5, 1,1)

		self.superposeCheck = QtWidgets.QCheckBox(self.topGroupBox)
		self.superposeCheck.setObjectName("superposeCheck")
		self.superposeCheck.setText("Superpose reference onto target")
		self.topLayout.addWidget(self.superposeCheck, 3, 4, 1, 2)		

		self.tabs = QtWidgets.QTabWidget(self.splitter)
		self.tabs.setObjectName("tabs")

		self.middleSplitter = QtWidgets.QSplitter(self.tabs)
		self.middleSplitter.setObjectName("middleSplitter")
		self.middleSplitter.setOrientation(QtCore.Qt.Horizontal)
		self.middleSplitter.setHandleWidth(10)
		#self.middleSplitter.setStyleSheet("QSplitter::handle{image:url("+os.path.join(os.path.dirname(__file__),"img/splitter_h.png")+");}");
		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
		self.middleSplitter.setSizePolicy(policy)

		self.tabs.addTab(self.middleSplitter, "General")

		self.tree = QtWidgets.QTreeView(self.middleSplitter)
		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
		self.tree.setSizePolicy(policy)
		self.model = QtWidgets.QFileSystemModel(self.tree)
		self.tree.setModel(self.model)
		self.model.setNameFilters(["*.pdb", "*.ent"])
		self.model.setNameFilterDisables(False)
		self.tree.hideColumn(1)
		self.tree.hideColumn(2)
		self.tree.header().hide()
		self.tree.header().setSectionResizeMode(QtWidgets.QHeaderView.Stretch)
		self.tree.sortByColumn(3, QtCore.Qt.AscendingOrder)
		self.tree.setSortingEnabled(True)
		self.tree.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)

		self.targetLayoutWidget = QtWidgets.QWidget(self.middleSplitter)
		self.targetLayoutWidget.setObjectName("targetLayoutWidget")

		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
		self.targetLayoutWidget.setSizePolicy(policy)

		self.targetLayout = QtWidgets.QGridLayout(self.targetLayoutWidget)
		self.targetLayout.setObjectName("targetLayout")
		self.targetLayout.setContentsMargins(0, 0, 0, 0)

		self.targetLabel = QtWidgets.QLabel(self.targetLayoutWidget)
		self.targetLabel.setObjectName("targetLabel")
		self.targetLabel.setText("Reference")
		self.targetLayout.addWidget(self.targetLabel, 0, 0, 1, 7)

		self.targetBrowser = QtWebEngineWidgets.QWebEngineView(self.targetLayoutWidget)
		self.targetBrowser.setObjectName("targetBrowser")
		self.targetBrowser.page().setBackgroundColor(QtCore.Qt.black)
		self.targetBrowser.setSizePolicy(policy)
		self.targetLayout.addWidget(self.targetBrowser, 1, 0, 1, 7)

		spacerItem = QtWidgets.QSpacerItem(40 ,20 ,QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
		self.targetLayout.addItem(spacerItem, 2, 0, 1, 1)

		self.representationLabel = QtWidgets.QLabel(self.targetLayoutWidget)
		self.representationLabel.setObjectName("representationLabel")
		self.representationLabel.setText("Representation")
		self.targetLayout.addWidget(self.representationLabel, 2, 1, 1, 1)
		self.representationValue = QtWidgets.QComboBox(self.targetLayoutWidget)
		self.representationValue.setObjectName("representationValue")
		self.representationValue.addItems(["cartoon" , "backbone", "licorice"])
		self.targetLayout.addWidget(self.representationValue, 2, 2, 1, 1)        
		self.colorLabel = QtWidgets.QLabel(self.targetLayoutWidget)
		self.colorLabel.setObjectName("colorLabel")
		self.colorLabel.setText("Color")
		self.targetLayout.addWidget(self.colorLabel, 2, 3, 1, 1)
		self.colorValue = QtWidgets.QComboBox(self.targetLayoutWidget)
		self.colorValue.setObjectName("colorValue")
		self.colorValue.addItems(["secondary structure" , "residue", "chain id"])
		self.targetLayout.addWidget(self.colorValue, 2, 4, 1, 1)
		self.line3 = QtWidgets.QFrame(self.targetLayoutWidget)
		self.line3.setFrameShape(QtWidgets.QFrame.VLine)
		self.line3.setFrameShadow(QtWidgets.QFrame.Sunken)
		self.line3.setObjectName("line3")
		self.targetLayout.addWidget(self.line3, 2, 5, 1, 1)
		self.saveButton = QtWidgets.QPushButton(self.targetLayoutWidget)
		self.saveButton.setObjectName("saveButton")
		self.saveButton.setIcon(QtGui.QIcon(os.path.join(os.path.dirname(__file__),"img/screenshot.png")))
		self.targetLayout.addWidget(self.saveButton, 2, 6, 1, 1)

		self.referenceLayoutWidget = QtWidgets.QWidget(self.middleSplitter)
		self.referenceLayoutWidget.setObjectName("referenceLayoutWidget")

		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
		self.referenceLayoutWidget.setSizePolicy(policy)

		self.referenceLayout = QtWidgets.QGridLayout(self.referenceLayoutWidget)
		self.referenceLayout.setObjectName("referenceLayout")
		self.referenceLayout.setContentsMargins(0, 0, 0, 0)

		self.targetBrowserLabel = QtWidgets.QLabel(self.targetLayoutWidget)
		self.targetBrowserLabel.setObjectName("targetBrowserLabel")
		self.targetBrowserLabel.setText("Target")
		self.referenceLayout.addWidget(self.targetBrowserLabel, 0, 0, 1, 7)

		self.referenceBrowser = QtWebEngineWidgets.QWebEngineView(self.referenceLayoutWidget)
		self.referenceBrowser.setObjectName("referenceBrowser")
		self.referenceBrowser.page().setBackgroundColor(QtCore.Qt.black)
		self.referenceBrowser.setSizePolicy(policy)

		self.referenceLayout.addWidget(self.referenceBrowser, 1, 0, 1, 7)

		spacerItem = QtWidgets.QSpacerItem(40 ,20 ,QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
		self.referenceLayout.addItem(spacerItem, 2, 0, 1, 1)

		self.representationReferenceLabel = QtWidgets.QLabel(self.referenceLayoutWidget)
		self.representationReferenceLabel.setObjectName("representationReferenceLabel")
		self.representationReferenceLabel.setText("Representation")
		self.referenceLayout.addWidget(self.representationReferenceLabel, 2, 1, 1, 1)
		self.representationReferenceValue = QtWidgets.QComboBox(self.referenceLayoutWidget)
		self.representationReferenceValue.setObjectName("representationReferenceValue")
		self.representationReferenceValue.addItems(["cartoon" , "backbone", "licorice"])
		self.referenceLayout.addWidget(self.representationReferenceValue, 2, 2, 1, 1)        
		self.colorReferenceLabel = QtWidgets.QLabel(self.referenceLayoutWidget)
		self.colorReferenceLabel.setObjectName("colorReferenceLabel")
		self.colorReferenceLabel.setText("Color")
		self.referenceLayout.addWidget(self.colorReferenceLabel, 2, 3, 1, 1)
		self.colorReferenceValue = QtWidgets.QComboBox(self.referenceLayoutWidget)
		self.colorReferenceValue.setObjectName("colorReferenceValue")
		self.colorReferenceValue.addItems(["secondary structure" , "residue", "chain id"])
		self.referenceLayout.addWidget(self.colorReferenceValue, 2, 4, 1, 1)
		self.line4 = QtWidgets.QFrame(self.referenceLayoutWidget)
		self.line4.setFrameShape(QtWidgets.QFrame.VLine)
		self.line4.setFrameShadow(QtWidgets.QFrame.Sunken)
		self.line4.setObjectName("line4")
		self.referenceLayout.addWidget(self.line4, 2, 5, 1, 1)
		self.saveButton2 = QtWidgets.QPushButton(self.referenceLayoutWidget)
		self.saveButton2.setObjectName("saveButton2")
		self.saveButton2.setIcon(QtGui.QIcon(os.path.join(os.path.dirname(__file__),"img/screenshot.png")))
		self.referenceLayout.addWidget(self.saveButton2, 2, 6, 1, 1) 

		self.advancedWidget = QtWidgets.QWidget(self.tabs)
		self.tabs.addTab(self.advancedWidget, "Advanced")

		self.advancedWidget.setObjectName("advancedWidget")
		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
		self.advancedWidget.setSizePolicy(policy)

		self.advancedLayout = QtWidgets.QGridLayout(self.advancedWidget)
		self.advancedLayout.setObjectName("advancedLayout")
		self.advancedLayout.setContentsMargins(0, 0, 0, 0)

		self.textOutput = QtWidgets.QTextEdit(self.splitter)
		self.textOutput.setObjectName("textOutput")
		self.textOutput.setReadOnly(True)

		self.gridLayout.addWidget(self.splitter, 0, 0, 1, 1)
